==> mopac_22.0.6+dfsg.orig.tar.xz: mopac-22.0.6/tests/regenerate_tests.sh <==
mopac port.mop
rm port.arc
rm port.aux
rm port.den
rm port.esp
rm port.esr
rm port.gpt
rm port.html
rm port.pdb
rm port.pol
rm port.res
rm port.txt
rm port.ump
rm port.xyz
rm parameters_for_PM8_C.F90

mopac Crambin_1SCF.mop
rm Crambin_1SCF.arc
rm Crambin_1SCF.log
rm Crambin_1SCF.pdb
rm Crambin_1SCF.den

mopac test_Lewis_for_Proteins.mop
rm test_Lewis_for_Proteins.html
rm test_Lewis_for_Proteins.pdb
rm test_Lewis_for_Proteins.txt

mopac Test_XENO.mop
rm Test_XENO.arc
rm Test_XENO.html
rm Test_XENO.pdb
rm Test_XENO.txt

mopac Test_Hetero_group.mop
rm Test_Hetero_group.arc
rm Test_Hetero_group.log
rm Test_Hetero_group.pdb

mopac convert_an_edited_PDB_file.mop
rm convert_an_edited_PDB_file.arc
rm convert_an_edited_PDB_file.html
rm convert_an_edited_PDB_file.log
rm convert_an_edited_PDB_file.pdb
rm convert_an_edited_PDB_file.txt

mopac convert_an_un-edited_PDB_file.mop
rm convert_an_un-edited_PDB_file.arc
rm convert_an_un-edited_PDB_file.log
rm convert_an_un-edited_PDB_file.pdb

mopac Check_that_TERs_are_preserved.mop
rm Check_that_TERs_are_preserved.arc
rm Check_that_TERs_are_preserved.html
rm Check_that_TERs_are_preserved.pdb
rm Check_that_TERs_are_preserved.txt

mopac Compare_two_protein_structures.mop
rm Compare_two_protein_structures.html
rm Compare_two_protein_structures.txt
rm Compare_two_protein_structures_Structure-1.pdb
rm Compare_two_protein_structures_Structure-2.pdb

mopac PDB1CBN.ent
rm PDB1CBN.log
rm PDB1CBN.pdb
rm PDB1CBN.arc

mopac PDB1EJG.ent
rm PDB1EJG.log
rm PDB1EJG.pdb
rm PDB1EJG.arc

mopac Compare_PDB_1EJG_and_1CBN.mop
rm Compare_PDB_1EJG_and_1CBN.html
rm Compare_PDB_1EJG_and_1CBN.txt
rm Compare_PDB_1EJG_and_1CBN_PDB1CBN.pdb
rm Compare_PDB_1EJG_and_1CBN_PDB1EJG.pdb

mopac Compare_PDB_Bacteriorhodopsin_1AP9_and_2AT9.mop
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_2AT9.html
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_2AT9.txt
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_2AT9_Bacteriorhodopsin_1AP9.pdb
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_2AT9_Bacteriorhodopsin_2AT9.pdb

mopac Compare_PDB_Bacteriorhodopsin_1AP9_and_1C3W.mop
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1C3W.html
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1C3W.txt
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1C3W_Bacteriorhodopsin_1AP9.pdb
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1C3W_Bacteriorhodopsin_1C3W.pdb

mopac Compare_PDB_Bacteriorhodopsin_1AP9_and_1BRX.mop
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1BRX.html
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1BRX.txt
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1BRX_Bacteriorhodopsin_1AP9.pdb
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1BRX_Bacteriorhodopsin_1BRX.pdb

mopac Compare_PDB_Bacteriorhodopsin_1AP9_and_1BRR.mop
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1BRR.html
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1BRR.txt
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1BRR_Bacteriorhodopsin_1AP9.pdb
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1BRR_Bacteriorhodopsin_1BRR.pdb

mopac Compare_PDB_Bacteriorhodopsin_1AP9_and_1AT9.mop
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1AT9.html
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1AT9.txt
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1AT9_ADD-H_Bacteriorhodopsin_1AP9.pdb
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1AT9_ADD-H_Bacteriorhodopsin_1AT9.pdb

mopac ADD-H_Bacteriorhodopsin_1AP9.mop
rm ADD-H_Bacteriorhodopsin_1AP9.html
rm ADD-H_Bacteriorhodopsin_1AP9.log
rm ADD-H_Bacteriorhodopsin_1AP9.arc
rm ADD-H_Bacteriorhodopsin_1AP9.pdb
rm ADD-H_Bacteriorhodopsin_1AP9.txt

mopac ADD-H_Bacteriorhodopsin_1AT9.mop
rm ADD-H_Bacteriorhodopsin_1AT9.log
rm ADD-H_Bacteriorhodopsin_1AT9.arc

mopac Au_Add-H.mop
rm Au_Add-H.arc
rm Au_Add-H.log

mopac Compare_ADD-H_1EJG_and_1CBN.mop
rm Compare_ADD-H_1EJG_and_1CBN.html
rm Compare_ADD-H_1EJG_and_1CBN.txt
rm Compare_ADD-H_1EJG_and_1CBN_PDB1CBN.pdb
rm Compare_ADD-H_1EJG_and_1CBN_PDB1EJG.pdb

mopac Locate_TS.mop
rm Locate_TS.html
rm Locate_TS.log
rm Locate_TS.pdb
rm Locate_TS.arc
rm Locate_TS.txt
rm "Locate_TS 30p0 first.mop"
rm "Locate_TS 60p0 first.mop"
rm "Locate_TS 120p0 first.mop"
rm "Locate_TS 30p0 second.mop"
rm "Locate_TS 60p0 second.mop"
rm "Locate_TS 120p0 second.mop"
rm "Locate_TS 30p0 average.mop"
rm "Locate_TS 60p0 average.mop"
rm "Locate_TS 120p0 average.mop"
rm "Locate_TS Loop1.mop"
rm "Locate_TS Loop2.mop"
rm "Locate_TS Loop3.mop"
rm "Locate_TS Loop4.mop"
rm "Locate_TS Loop5.mop"

mopac IONIZE.mop
rm IONIZE.arc
rm IONIZE.html
rm IONIZE.pdb
rm IONIZE.txt

mopac SALT.mop
rm SALT.arc

mopac SALT_2.mop
rm SALT_2.arc

mopac SITE_Individual_residues.mop
rm SITE_Individual_residues.arc

mopac erratic1.mop
rm erratic1.arc

mopac erratic2.mop
rm erratic2.arc

==> mopac_23.1.2.orig.tar.xz: mopac-23.1.2/tests/regenerate_tests.sh <==
mopac port.mop
rm port.arc
rm port.aux
rm port.den
rm port.esp
rm port.esr
rm port.gpt
rm port.html
rm port.pdb
rm port.pol
rm port.res
rm port.txt
rm port.ump
rm port.xyz
rm parameters_for_PM6_ORG_C.F90

mopac Crambin_1SCF.mop
rm Crambin_1SCF.arc
rm Crambin_1SCF.log
rm Crambin_1SCF.pdb
rm Crambin_1SCF.den

mopac test_Lewis_for_Proteins.mop
rm test_Lewis_for_Proteins.arc
rm test_Lewis_for_Proteins.html
rm test_Lewis_for_Proteins.pdb
rm test_Lewis_for_Proteins.txt

mopac Test_XENO.mop
rm Test_XENO.arc
rm Test_XENO.html
rm Test_XENO.pdb
rm Test_XENO.txt

mopac Test_Hetero_group.mop
rm Test_Hetero_group.arc
rm Test_Hetero_group.log
rm Test_Hetero_group.pdb

mopac convert_an_edited_PDB_file.mop
rm convert_an_edited_PDB_file.arc
rm convert_an_edited_PDB_file.html
rm convert_an_edited_PDB_file.log
rm convert_an_edited_PDB_file.pdb
rm convert_an_edited_PDB_file.txt

mopac convert_an_un-edited_PDB_file.mop
rm convert_an_un-edited_PDB_file.arc
rm convert_an_un-edited_PDB_file.log
rm convert_an_un-edited_PDB_file.pdb

mopac Check_that_TERs_are_preserved.mop
rm Check_that_TERs_are_preserved.arc
rm Check_that_TERs_are_preserved.html
rm Check_that_TERs_are_preserved.pdb
rm Check_that_TERs_are_preserved.txt

# other tests depend on outputs
mopac ADD-H_Bacteriorhodopsin_1AP9.mop
mopac ADD-H_Bacteriorhodopsin_1AT9.mop
mopac PDB1CBN.ent
mopac PDB1EJG.ent

mopac Compare_two_protein_structures.mop
rm Compare_two_protein_structures.html
rm Compare_two_protein_structures.txt
rm Compare_two_protein_structures_Structure-1.pdb
rm Compare_two_protein_structures_Structure-2.pdb

mopac Compare_PDB_1EJG_and_1CBN.mop
rm Compare_PDB_1EJG_and_1CBN.html
rm Compare_PDB_1EJG_and_1CBN.txt
rm Compare_PDB_1EJG_and_1CBN_PDB1CBN.pdb
rm Compare_PDB_1EJG_and_1CBN_PDB1EJG.pdb

mopac Compare_PDB_Bacteriorhodopsin_1AP9_and_2AT9.mop
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_2AT9.html
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_2AT9.txt
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_2AT9_Bacteriorhodopsin_1AP9.pdb
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_2AT9_Bacteriorhodopsin_2AT9.pdb

mopac Compare_PDB_Bacteriorhodopsin_1AP9_and_1C3W.mop
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1C3W.html
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1C3W.txt
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1C3W_Bacteriorhodopsin_1AP9.pdb
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1C3W_Bacteriorhodopsin_1C3W.pdb

mopac Compare_PDB_Bacteriorhodopsin_1AP9_and_1BRX.mop
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1BRX.html
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1BRX.txt
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1BRX_Bacteriorhodopsin_1AP9.pdb
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1BRX_Bacteriorhodopsin_1BRX.pdb

mopac Compare_PDB_Bacteriorhodopsin_1AP9_and_1BRR.mop
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1BRR.html
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1BRR.txt
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1BRR_Bacteriorhodopsin_1AP9.pdb
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1BRR_Bacteriorhodopsin_1BRR.pdb

mopac Compare_PDB_Bacteriorhodopsin_1AP9_and_1AT9.mop
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1AT9.html
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1AT9.txt
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1AT9_ADD-H_Bacteriorhodopsin_1AP9.pdb
rm Compare_PDB_Bacteriorhodopsin_1AP9_and_1AT9_ADD-H_Bacteriorhodopsin_1AT9.pdb

mopac Au_Add-H.mop
rm Au_Add-H.arc
rm Au_Add-H.log

mopac Compare_ADD-H_1EJG_and_1CBN.mop
rm Compare_ADD-H_1EJG_and_1CBN.html
rm Compare_ADD-H_1EJG_and_1CBN.txt
rm Compare_ADD-H_1EJG_and_1CBN_PDB1CBN.pdb
rm Compare_ADD-H_1EJG_and_1CBN_PDB1EJG.pdb

# remove intermediate files later
rm ADD-H_Bacteriorhodopsin_1AP9.html
rm ADD-H_Bacteriorhodopsin_1AP9.log
rm ADD-H_Bacteriorhodopsin_1AP9.arc
rm ADD-H_Bacteriorhodopsin_1AP9.pdb
rm ADD-H_Bacteriorhodopsin_1AP9.txt
rm ADD-H_Bacteriorhodopsin_1AT9.log
rm ADD-H_Bacteriorhodopsin_1AT9.arc
rm PDB1CBN.log
rm PDB1CBN.pdb
rm PDB1CBN.arc
rm PDB1EJG.log
rm PDB1EJG.pdb
rm PDB1EJG.arc

mopac Locate_TS.mop
rm Locate_TS.html
rm Locate_TS.log
rm Locate_TS.pdb
rm Locate_TS.arc
rm Locate_TS.txt
rm "Locate_TS bias=120.0 average.mop"
rm "Locate_TS bias=120.0 first.mop"
rm "Locate_TS bias=120.0 second.mop"
rm "Locate_TS bias=30.0 average.mop"
rm "Locate_TS bias=30.0 first.mop"
rm "Locate_TS bias=30.0 second.mop"
rm "Locate_TS bias=60.0 average.mop"
rm "Locate_TS bias=60.0 first.mop"
rm "Locate_TS bias=60.0 second.mop"
rm "Locate_TS Loop1.mop"
rm "Locate_TS Loop2.mop"
rm "Locate_TS Loop3.mop"
rm "Locate_TS Loop4.mop"
rm "Locate_TS Loop5.mop"

#delay removal of intermediate files
mopac IONIZE.mop

mopac SALT.mop
rm SALT.arc

mopac SALT_2.mop
rm SALT_2.arc

mopac SITE_Individual_residues.mop
rm SITE_Individual_residues.arc

#delayed removal
rm IONIZE.arc
rm IONIZE.html
rm IONIZE.pdb
rm IONIZE.txt

mopac erratic1.mop
rm erratic1.arc

mopac erratic2.mop
rm erratic2.arc

mopac erratic3.mop
rm erratic3.arc
